.. highlight:: shell

============
Installation
============

Stable release
--------------

The standard asyncio-rpc distribution is pretty lightweight, installing as little dependencies
as possible. Install it like this::

    $ pip install asyncio-rpc

If you don't have `pip`_ installed, this `Python installation guide`_ can guide
you through the process.

.. _pip: https://pip.pypa.io
.. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/


From sources
------------

The sources for asyncio-rpc can be downloaded from the `Github repo`_.

You can either clone the public repository:

.. code-block:: console

    $ git clone git://github.com/nens/asyncio-rpc

Or download the `tarball`_:

.. code-block:: console

    $ curl  -OL https://github.com/nens/asyncio-rpc/tarball/master

Once you have a copy of the source, you can install it with:

.. code-block:: console

    $ python setup.py install


.. _Github repo: https://github.com/nens/asyncio-rpc
.. _tarball: https://github.com/nens/ascynio-rpc/tarball/master
